@@ -10,7 +10,6 @@ class Authenticate:
         self.config_file = os.path.join(os.path.expanduser("~"), '.bbpp/bbpp.conf')
 
         if username and password:
-            print(username, password)
             self._write_config_file(username=username, password=password)
         else:
             self.check_config_file_exists()
@@ -32,5 +31,4 @@ class Authenticate:
     def _read_config_file(self):
         with open(self.config_file, 'r') as f:
             config = json.loads(f.read())
-            print(config)
             return config
